import React from "react";
import { Link } from "react-router-dom";

import logo from "../../assets/12345.jpeg";
import { Button } from "../button";
import { withRouter } from "react-router-dom";

import { LocalContext, languages } from "../../utils/localContext";
import { SCCV } from "../../utils/setSCCvariables";

import "./style.scss";

class Header extends React.Component {
	static contextType = LocalContext;

	constructor(props) {
		super(props);
		// console.log("constructor HEADER");
		this.state = { login: false };
	}

	componentDidMount() {
		console.log("componentDidMount HEADER", this.context);
	}

	logIn = () =>
		new Promise(resolve => {
			setTimeout(() => {
				this.setState(prevState => ({ ...prevState, login: !prevState.login }));
			}, 2000);
		});

	logOut = () =>
		new Promise(resolve => {
			setTimeout(() => {
				this.setState(prevState => ({ ...prevState, login: !prevState.login }));
			}, 2000);
		});

	emptyClick = () => {
		this.props.history.push("/sdasdfhghjutyhtgrfedvgbv");
	};

	changeLanguage = e => {
		this.context.setLanguage(e.target.value);
	};

	changeTheme = e => {
		this.context.setCssVariables(e.target.value);
	};

	render() {
		const { login } = this.state;
		const { randomNumber } = this.props;
		const { json, lang, theme } = this.context;

		if (randomNumber < 50) {
			// return this.props.history.push("/sdasdfhghjutyhtgrfedvgbv");
			// return <Redirect to="/iii33i3i3ii33i3i3i" />;
		}

		// console.log("THIS>, HEADER", this.props);
		return (
			<header className="header">
				<div className="header__logo-box">
					<img src={logo} alt="logo" className="header__logo" />
				</div>

				<div>
					<p>{json.hello}</p>
				</div>

				<div>
					<select value={lang} onChange={this.changeLanguage}>
						{languages.map(el => (
							<option key={el.name} value={el.name}>
								{el.title}
							</option>
						))}
					</select>
					<select value={theme} onChange={this.changeTheme}>
						{Object.keys(SCCV).map(el => (
							<option key={el} value={el}>
								{el}
							</option>
						))}
					</select>
				</div>

				<nav>
					<ul>
						<li>
							<Link
								to={{
									pathname: "/",
									search: "?name=Tony&age=55"
								}}>
								Main
							</Link>
						</li>
						<li>
							<Link to="/about-us">About us</Link>
						</li>
						<li>
							<Link to="/todo">Todo</Link>
						</li>
						<li>
							<Link to="/auth">Auth</Link>
						</li>
						<li>
							<Link to="/redux-todo">redux todo</Link>
						</li>
						<li>
							<Link to="/thunk-todo">Thunk todo</Link>
						</li>
						<li>
							<Link to="/hooks">Hooks</Link>
						</li>
					</ul>
				</nav>

				<div>Random - {randomNumber}</div>

				<button onClick={this.emptyClick}>404 page</button>

				{login ? (
					<Button className="header__button" onClick={this.logOut}>
						Log Out
					</Button>
				) : (
					<Button className="header__button" onClick={this.logIn}>
						Log In
					</Button>
				)}
				{/* <Button onClick={this.logIn}>Log In</Button> 
			<Button onClick={this.logOut}>Log Out</Button>  */}
			</header>
		);
	}
}

export default withRouter(Header);
