import React from "react";
import { Switch, Route } from "react-router-dom";

import Layout from "./components/layout";
import Main from "./containers/main";
import Item from "./containers/item";
import AboutUs from "./containers/aboutUs";
import Todo from "./containers/todo";
import Auth from "./containers/auth";
import TodoRedux from "./containers/todoRedux";
import ThunkTodo from "./containers/thunkTodo";
import { Hooks } from "./containers/hooks";

import { LocalContext, setLanguage } from "./utils/localContext";
import { setCssVariables } from "./utils/setSCCvariables";
import { GLOBAL_DEFAULT_THEME } from "./contants";

export class Router extends React.Component {
	constructor(props) {
		super(props);

		const themeFromLocalStorage = localStorage.getItem("theme");

		this.state = {
			lang: navigator.language,
			langJson: setLanguage(navigator.language),
			theme: themeFromLocalStorage || GLOBAL_DEFAULT_THEME
		};

		setCssVariables(themeFromLocalStorage ? themeFromLocalStorage : GLOBAL_DEFAULT_THEME);
	}

	setLanguage = lang => {
		this.setState({ lang, langJson: setLanguage(lang) });
	};

	setTheme = theme => {
		setCssVariables(theme);
		this.setState({ theme });
		localStorage.setItem("theme", theme);
	};

	render() {
		return (
			<LocalContext.Provider
				value={{
					lang: this.state.lang,
					json: this.state.langJson,
					setLanguage: this.setLanguage,
					setCssVariables: this.setTheme,
					theme: this.state.theme
				}}>
				<Switch>
					<Route
						exact
						path="/"
						render={props => (
							<Layout footer={false} wrapperClassName="main">
								<Main {...props} />
							</Layout>
						)}
					/>
					<Route
						exact
						path="/auth"
						render={props => (
							<Layout footer={false} wrapperClassName="main">
								<Auth {...props} />
							</Layout>
						)}
					/>
					<Route
						exact
						path="/redux-todo"
						render={props => (
							<Layout footer={false} wrapperClassName="main">
								<TodoRedux {...props} />
							</Layout>
						)}
					/>
					<Route
						exact
						path="/todo"
						render={props => (
							<Layout footer={false} wrapperClassName="main">
								<Todo {...props} />
							</Layout>
						)}
					/>
					<Route
						exact
						path="/thunk-todo"
						render={props => (
							<Layout footer={false} wrapperClassName="main">
								<ThunkTodo {...props} />
							</Layout>
						)}
					/>
					<Route
						exact
						path="/item/:id"
						render={props => (
							<Layout footer={false} wrapperClassName="main">
								<Item {...props} />
							</Layout>
						)}
					/>
					<Route
						exact
						path="/hooks"
						render={props => (
							<Layout footer={false} wrapperClassName="main">
								<Hooks {...props} />
							</Layout>
						)}
					/>
					<Route exact path="/about-us" component={AboutUs} />
					<Route
						exact
						render={() => (
							<Layout footer={false} wrapperClassName="main">
								<div>Page not found</div>
							</Layout>
						)}
					/>
				</Switch>
			</LocalContext.Provider>
		);
	}
}
